@@ -58,6 +58,8 @@ pub enum AdminRequestCli {
     RegisterDna(RegisterDna),
     InstallApp(InstallApp),
     InstallAppBundle(InstallAppBundle),
+    /// Calls AdminRequest::UninstallApp.
+    UninstallApp(UninstallApp),
     /// Calls AdminRequest::ListAppInterfaces.
     ListAppWs,
     /// Calls AdminRequest::ListDnas.
@@ -161,6 +163,14 @@ pub struct InstallAppBundle {
     pub uid: Option<Uid>,
 }
 
+#[derive(Debug, StructOpt, Clone)]
+/// Calls AdminRequest::UninstallApp
+/// and uninstalls the specified app.
+pub struct UninstallApp {
+    /// The InstalledAppId to uninstall.
+    pub app_id: String,
+}
+
 #[derive(Debug, StructOpt, Clone)]
 /// Calls AdminRequest::EnableApp
 /// and activates the installed app.
@@ -290,6 +300,11 @@ async fn call_inner(cmd: &mut CmdRunner, call: AdminRequestCli) -> anyhow::Resul
             let app = install_app_bundle(cmd, args).await?;
             msg!("Installed App: {}", app.installed_app_id,);
         }
+        AdminRequestCli::UninstallApp(args) => {
+            let app_id = args.app_id.clone();
+            uninstall_app(cmd, args).await?;
+            msg!("Uninstalled App: {}", app_id,);
+        }
         AdminRequestCli::ListDnas => {
             let dnas = list_dnas(cmd).await?;
             msg!("Dnas: {:?}", dnas);
@@ -513,6 +528,21 @@ pub async fn install_app_bundle(
     Ok(installed_app)
 }
 
+/// Calls [`AdminRequest::UninstallApp`] and uninstalls the installed app.
+pub async fn uninstall_app(cmd: &mut CmdRunner, args: UninstallApp) -> anyhow::Result<()> {
+    let resp = cmd
+        .command(AdminRequest::UninstallApp {
+            installed_app_id: args.app_id,
+        })
+        .await?;
+
+    assert!(
+        matches!(resp, AdminResponse::AppUninstalled),
+        "Failed to uninstall app"
+    );
+    Ok(())
+}
+
 /// Calls [`AdminRequest::ListAppInterfaces`].
 pub async fn list_app_ws(cmd: &mut CmdRunner) -> anyhow::Result<Vec<u16>> {
     let resp = cmd.command(AdminRequest::ListAppInterfaces).await?;
